@@ -28,6 +28,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "greeterapp.h"
 
+#include <config-kscreenlocker.h>
+#if HAVE_SYS_PRCTL_H
+#include <sys/prctl.h>
+#endif
+
 static void signalHandler(int signum)
 {
     ScreenLocker::UnlockApp *instance = qobject_cast<ScreenLocker::UnlockApp *>(QCoreApplication::instance());
@@ -51,6 +56,11 @@ static void signalHandler(int signum)
 
 int main(int argc, char* argv[])
 {
+    // disable ptrace on the greeter
+#if HAVE_PR_SET_DUMPABLE
+    prctl(PR_SET_DUMPABLE, 0);
+#endif
+
     KLocalizedString::setApplicationDomain("kscreenlocker_greet");
 
     // explicitly disable input methods as it makes it impossible to unlock, see BUG 306932
@@ -78,6 +88,12 @@ int main(int argc, char* argv[])
 
     QCommandLineOption testingOption(QStringLiteral("testing"),
                                      i18n("Starts the greeter in testing mode"));
+
+    QCommandLineOption themeOption(QStringLiteral("theme"),
+                                     i18n("Starts the greeter with the selected theme (only in Testing mode)"),
+                                     QStringLiteral("theme"),
+                                     QStringLiteral(""));
+
     QCommandLineOption immediateLockOption(QStringLiteral("immediateLock"),
                                            i18n("Lock immediately, ignoring any grace time etc."));
     QCommandLineOption graceTimeOption(QStringLiteral("graceTime"),
@@ -91,6 +107,7 @@ int main(int argc, char* argv[])
                                        QStringLiteral("fd"));
 
     parser.addOption(testingOption);
+    parser.addOption(themeOption);
     parser.addOption(immediateLockOption);
     parser.addOption(graceTimeOption);
     parser.addOption(nolockOption);
@@ -100,6 +117,17 @@ int main(int argc, char* argv[])
     if (parser.isSet(testingOption)) {
         app.setTesting(true);
         app.setImmediateLock(true);
+
+        //parse theme option
+        const QString theme = parser.value(themeOption);
+        if (!theme.isEmpty()) {
+            app.setTheme(theme);
+        }
+
+        // allow ptrace if testing is enabled
+#if HAVE_PR_SET_DUMPABLE
+        prctl(PR_SET_DUMPABLE, 1);
+#endif
     } else {
         app.setImmediateLock(parser.isSet(immediateLockOption));
     }
